@@ -84,7 +84,6 @@ public:
     ReminderTreeItem(const Akonadi::Item &incidence, QTreeWidget *parent)
         : QTreeWidgetItem(parent)
         , mIncidence(incidence)
-        , mNotified(false)
     {
     }
 
@@ -100,7 +99,7 @@ public:
     QDateTime mRemindAt;
     QDateTime mTrigger;
     QDateTime mHappening;
-    bool mNotified;
+    bool mNotified = false;
 };
 
 struct ConfItem {
@@ -364,7 +363,7 @@ static QString cleanSummary(const QString &summary)
     retStr.replace(QLatin1Char('\n'), QLatin1Char(' '));
     if (retStr.length() > maxLen) {
         maxLen -= etc.length();
-        retStr = retStr.left(maxLen);
+        retStr.truncate(maxLen);
         retStr += etc;
     }
     return retStr;
@@ -733,7 +732,7 @@ void AlarmDialog::eventNotification()
                          it != end; ++it) {
                         add << (*it).fullName();
                     }
-                    to = add.join(QStringLiteral(", "));
+                    to = add.join(QLatin1String(", "));
                 }
 
                 QString subject;
